@@ -22,7 +22,7 @@ __version__ = "2019.01.09"
 __license__ = "MIT"
 
 
-def make3DPlot(func, legend="", npoints=200):
+def make3DPlot(func, legend="", npoints=100):
 
     str1 = legend.split("'")[0]
     str2 = legend.split("'")[1]
@@ -39,6 +39,7 @@ def make3DPlot(func, legend="", npoints=200):
     count = 0
     for cu in range(len(u)):
         for cv in range(len(v)):
+
             r_tmp = func(u[cu], v[cv])
             z = r_tmp * np.cos(u[cu])
             x = r_tmp * np.sin(u[cu]) * np.cos(v[cv])
@@ -61,7 +62,7 @@ def make3DPlot(func, legend="", npoints=200):
     return (dataX, dataY, dataZ, dataR)
 
 
-def make3DPlotPosNeg(func, legend="", npoints=200):
+def make3DPlotPosNeg(func, legend="", npoints=100):
 
     u = np.linspace(0, np.pi, npoints)
     v = np.linspace(0, 2 * np.pi, 2 * npoints)
@@ -129,7 +130,7 @@ def make3DPlotPosNeg(func, legend="", npoints=200):
     return ((dataX1, dataY1, dataZ1, dataR1), (dataX2, dataY2, dataZ2, dataR2))
 
 
-def make3DPlot2(func, legend="", npoints=50):
+def make3DPlot2(func, legend="", npoints=200):
 
     u = np.linspace(0, np.pi, npoints)
     v = np.linspace(0, np.pi, npoints)
@@ -205,7 +206,7 @@ def make3DPlot2(func, legend="", npoints=50):
     return ((dataX1, dataY1, dataZ1, dataR1), (dataX2, dataY2, dataZ2, dataR2))
 
 
-def make3DPlot3(func, legend="", width=600, height=600, npoints=50):
+def make3DPlot3(func, legend="", width=600, height=600, npoints=100):
 
     str1 = legend.split("'")[0]
     str2 = legend.split("'")[1]
@@ -301,7 +302,7 @@ def make3DPlot3(func, legend="", width=600, height=600, npoints=50):
 ################################################################################################
 
 
-def makePolarPlot(func, legend="", p="xy", npoints=90):
+def makePolarPlot(func, legend="", p="xy", npoints=200):
     u = np.linspace(0, 2 * np.pi, npoints)
     r = list(map(func, u))
     if p == "xy":
@@ -314,7 +315,7 @@ def makePolarPlot(func, legend="", p="xy", npoints=90):
     return (x, y)
 
 
-def makePolarPlotPosNeg(func, legend="", p="xy", npoints=90):
+def makePolarPlotPosNeg(func, legend="", p="xy", npoints=200):
 
     u = np.linspace(0, 2 * np.pi, npoints)
     r = list(map(lambda x: max(0, func(x)), u))
@@ -335,7 +336,7 @@ def makePolarPlotPosNeg(func, legend="", p="xy", npoints=90):
     return ((x1, y1), (x2, y2))
 
 
-def makePolarPlot2(func, legend="", p="xy", npoints=61):
+def makePolarPlot2(func, legend="", p="xy", npoints=200):
 
     u = np.linspace(0, 2 * np.pi, npoints)
     r = list(map(func, u))
@@ -354,7 +355,7 @@ def makePolarPlot2(func, legend="", p="xy", npoints=61):
     return ((x1, y1), (x2, y2))
 
 
-def makePolarPlot3(func, legend="", p="xy", npoints=61):
+def makePolarPlot3(func, legend="", p="xy", npoints=200):
 
     u = np.linspace(0, 2 * np.pi, npoints)
     r = list(map(func, u))
@@ -598,6 +599,7 @@ class ELATE:
 
         plotter = BackgroundPlotter()
 
+        plotter.set_background(color="white")
         x = None
         y = None
         z = None
@@ -658,11 +660,12 @@ class ELATE:
             func = self.YOUNG3D()
             colors = ["green"]
             for ix, icolor in zip(range(len(func)), colors):
-                x = np.array(func[ix][0])
-                y = np.array(func[ix][1])
-                z = np.array(func[ix][2])
-                r = np.array(func[ix][3])
-                if np.all((func[ix][0] == 0)):
+
+                x = np.array(func[0])
+                y = np.array(func[1])
+                z = np.array(func[2])
+                r = np.array(func[3])
+                if np.all((func[0] == 0)):
                     continue
                 else:
                     grid = pv.StructuredGrid(x, y, z)
@@ -671,8 +674,8 @@ class ELATE:
                     else:
                         plotter.add_mesh(grid, opacity=0.50, color=icolor)
 
-        plotter.add_axes()
-        plotter.show_grid()
+        # plotter.add_axes()
+        # plotter.show_grid(color = "black")
 
     def plot_2D(self, elastic_calc=""):
         import matplotlib.pyplot as plt
@@ -767,7 +770,7 @@ class ELATE:
             )
         )
         print(
-            "Young modulus  (GPa)  %9.3f %9.3f %9.3f "
+            "Young's modulus  (GPa)  %9.3f %9.3f %9.3f "
             % (
                 self.elas.averages()[0][2],
                 self.elas.averages()[1][2],
@@ -775,7 +778,7 @@ class ELATE:
             )
         )
         print(
-            "Poisson ratio         %9.3f %9.3f %9.3f "
+            "Poisson's ratio         %9.3f %9.3f %9.3f "
             % (
                 self.elas.averages()[0][3],
                 self.elas.averages()[1][3],
@@ -812,16 +815,31 @@ class ELATE:
         # print(type((minE,maxE,minLC,maxLC,minG,maxG,minNu,maxNu)))
         # print("%9.3f GPa  %9.3f GPa  %9.3f TPa^-1   %9.3f TPa^-1    %9.3f GPa  %9.3f GPa  %9.3f  %9.3f" % (minE[1],maxE[1],minLC[1],maxLC[1],minG[1],maxG[1],minNu[1],maxNu[1]))
 
-        anisE = "%8.4f" % (maxE[1] / minE[1])
-        anisLC = ("%8.4f" % (maxLC[1] / minLC[1])) if minLC[1] > 0 else "&infin;"
-        anisG = "%8.4f" % (maxG[1] / minG[1])
+        anisE = "%8.3f" % (maxE[1] / minE[1])
+        anisLC = ("%8.3f" % (maxLC[1] / minLC[1])) if minLC[1] > 0 else "&infin;"
+        anisG = "%8.3f" % (maxG[1] / minG[1])
         anisNu = (
-            ("%8.4f" % (maxNu[1] / minNu[1])) if minNu[1] * maxNu[1] > 0 else "&infin;"
+            ("%8.3f" % (maxNu[1] / minNu[1])) if minNu[1] * maxNu[1] > 0 else "&infin;"
         )
 
         # print("       %s                     %s                                %s                         %s" % (anisE,anisLC,anisG,anisNu))
         # print(dirVec1(*minG[0]))
 
+        minEaxis = list(np.around(np.array(dirVec(*minE[0])), 3))
+        maxEaxis = list(np.around(np.array(dirVec(*maxE[0])), 3))
+        minLCaxis = list(np.around(np.array(dirVec(*minLC[0])), 3))
+        maxLCaxis = list(np.around(np.array(dirVec(*maxLC[0])), 3))
+
+        minGaxis = list(np.around(np.array(dirVec1(*minG[0])), 3))
+        maxGaxis = list(np.around(np.array(dirVec1(*maxG[0])), 3))
+        minG2ndaxis = list(np.around(np.array(dirVec2(*minG[0])), 3))
+        maxG2ndaxis = list(np.around(np.array(dirVec2(*maxG[0])), 3))
+
+        minNUaxis = list(np.around(np.array(dirVec1(*minNu[0])), 3))
+        maxNUaxis = list(np.around(np.array(dirVec1(*maxNu[0])), 3))
+        minNU2ndaxis = list(np.around(np.array(dirVec2(*minNu[0])), 3))
+        maxNU2ndaxis = list(np.around(np.array(dirVec2(*maxNu[0])), 3))
+
         print("\n \n                                  Min       Max   ||   Anisotropy")
         print(
             "----------------------------------------------------------------------------------------"
@@ -832,8 +850,12 @@ class ELATE:
         )
         print(
             "         Min Axis:    %s      \n         Max Axis:    %s "
-            % (str(tuple(dirVec(*minE[0]))), str(tuple(dirVec(*maxE[0]))))
+            % (str(tuple(minEaxis)), str(tuple(maxEaxis)))
         )
+        # print(
+        #     "         Min Axis:    %s      \n         Max Axis:    %s "
+        #     % (str(tuple(dirVec(*minE[0]))), str(tuple(dirVec(*maxE[0]))))
+        # )
         print(
             "----------------------------------------------------------------------------------------"
         )
@@ -843,7 +865,7 @@ class ELATE:
         )
         print(
             "         Min Axis:    %s      \n         Max Axis:    %s "
-            % (str(tuple(dirVec(*minLC[0]))), str(tuple(dirVec(*maxLC[0]))))
+            % (str(tuple(minLCaxis)), str(tuple(maxLCaxis)))
         )
         print(
             "----------------------------------------------------------------------------------------"
@@ -854,26 +876,26 @@ class ELATE:
         )
         print(
             "         Min Axis:    %s      \n         Max Axis:    %s "
-            % (str(tuple(dirVec1(*minG[0]))), str(tuple(dirVec1(*maxG[0]))))
+            % (str(tuple(minGaxis)), str(tuple(maxGaxis)))
         )
         print(
             "         Second Min Axis:    %s      \n         Second Max Axis:    %s "
-            % (str(tuple(dirVec2(*minG[0]))), str(tuple(dirVec2(*maxG[0]))))
+            % (str(tuple(minG2ndaxis)), str(tuple(minG2ndaxis)))
         )
         print(
             "----------------------------------------------------------------------------------------"
         )
         print(
-            "Poisson Ratio                 %9.3f %9.3f || %s "
+            "Poisson's Ratio                 %9.3f %9.3f || %s "
             % (minE[1], maxE[1], anisNu)
         )
         print(
             "         Min Axis:    %s      \n         Max Axis:    %s "
-            % (str(tuple(dirVec1(*minNu[0]))), str(tuple(dirVec1(*maxNu[0]))))
+            % (str(tuple(minNUaxis)), str(tuple(maxNUaxis)))
         )
         print(
             "         Second Min Axis:    %s      \n         Second Max Axis:    %s "
-            % (str(tuple(dirVec2(*minNu[0]))), str(tuple(dirVec2(*maxNu[0]))))
+            % (str(tuple(minNU2ndaxis)), str(tuple(maxNU2ndaxis)))
         )
 
 
