@@ -7,12 +7,13 @@ from ..utils.constants import *
 from ..utils.elements import ELEMENTS
 from ..utils.crystalutils import *
 from .structure import Structure
+from numpy import linalg as LA
 
 
 class ElasticProperties:
-    def __init__(self, elastic_tensor, structure=None, crystal_type=None):
+    def __init__(self, elastic_tensor, structure=None, crystal_type=None, code=None):
         """
-        
+
 
         Parameters
         ----------
@@ -32,8 +33,29 @@ class ElasticProperties:
         self.compaliance_tensor = self.elastic_tensor.I
         self.structure = structure
         self.crystal_type = crystal_type
+        print("\n------------------------------------------------------------------")
+        print("Elastic Tensor (GPa units)")
+        print("------------------------------------------------------------------\n")
+
+        printMatrix(self.elastic_tensor)
+        if code != None:
+            print("\nThis matrix was computed from " + code)
+        print("Note: For VASP users this is the pressure-corrected matrix")
+
+        print("\n------------------------------------------------------------------")
+        print("Elastic Tensor Eigen Values (GPa units)")
+        print("------------------------------------------------------------------\n")
+
+        positive_evals(self.elastic_tensor)
 
         if crystal_type is not None or structure is not None:
+            print(
+                "\n------------------------------------------------------------------"
+            )
+            print("Mechanical Stability Tests")
+            print(
+                "------------------------------------------------------------------\n"
+            )
             crystal_select(
                 cnew=self.elastic_tensor,
                 cell=self.structure.spglib_cell,
@@ -519,7 +541,35 @@ class ElasticProperties:
             Zenner Anisotropy only for Cubic Crystals.
 
         """
-        return self.anisotropy_zenner
+        return self.A_z
+
+    @property
+    def A_cb(self):
+        """
+
+
+        Returns
+        -------
+        float
+            Chung-Buessem only for Cubic Crystals.
+
+        """
+
+        a_cb = (self.G_v - self.G_r) / (self.G_v + self.G_r)
+        return a_cb
+
+    @property
+    def anisotropy_Chung_Buessem(self):
+        """
+
+
+        Returns
+        -------
+        float
+            Chung-Buessem  only for Cubic Crystals.
+
+        """
+        return self.A_cb
 
     @property
     def A_u(self):
@@ -570,6 +620,21 @@ class ElasticProperties:
         """
         return np.sqrt(5) * 2.303 * np.log(1 + (self.A_u / 5))
 
+    @property
+    def anisotropy_log_euclidean(self):
+        """
+
+
+        Returns
+        -------
+        float
+               log-Euclidean anisotropy parameter by Christopher M. Kube, AIP Advances 6, 095209 (2016)
+               AL  CV , CR   is based on the distance between the averaged stiffnesses CV and
+               CR , which is more appropriate. Clearly, AL  CV , CR   is zero when the crystallite is isotropic.
+
+        """
+        return self.A_l
+
     @property
     def ductility(self):
         """
@@ -689,8 +754,11 @@ class ElasticProperties:
         return 607 + 9.3 * self.K_vrh
 
     def print_properties(self):
+        print("\n------------------------------------------------------------------")
+        print("Elastic Moduli")
+        print("------------------------------------------------------------------\n")
 
-        print("\n \n                         Voigt     Reuss    Average")
+        print("                          Voigt     Reuss    Average")
         print("-------------------------------------------------------")
         print(
             "Bulk modulus   (GPa)  %9.3f %9.3f %9.3f "
@@ -701,11 +769,11 @@ class ElasticProperties:
             % (self.G_v, self.G_r, self.G_vrh)
         )
         print(
-            "Young modulus  (GPa)  %9.3f %9.3f %9.3f "
+            "Young's modulus  (GPa)  %9.3f %9.3f %9.3f "
             % (self.E_v, self.E_r, self.E_vrh)
         )
         print(
-            "Poisson ratio         %9.3f %9.3f %9.3f "
+            "Poisson's ratio         %9.3f %9.3f %9.3f "
             % (self.Nu_v, self.Nu_r, self.Nu_vrh)
         )
         print(
@@ -716,31 +784,66 @@ class ElasticProperties:
             "Bulk/Shear ratio      %9.3f %9.3f %9.3f (%s) "
             % (self.KG_ratio_v, self.KG_ratio_r, self.KG_ratio_vrh, self.ductility)
         )
-        print("-------------------------------------------------------")
 
-        print(" \n \n \t \t Elastic Anisotropy \n ")
-        print("Zener anisotropy (true for cubic crystals only) Az = %10.5f" % self.A_z)
+        print("\n------------------------------------------------------------------")
+        print("Elastic parameters")
+        print("------------------------------------------------------------------\n")
+
+        print("Lame's first and second parameter; Ref.[3]")
+        print("Lambda (GPa)  =  %10.3f  " % self.lambda_lame_coefficient)
+        print("Mu (GPa)  =  %10.3f  " % self.mu_lame_coefficient)
+
+        print("\n------------------------------------------------------------------")
+        print("Bonding information")
+        print("------------------------------------------------------------------\n ")
+
+        print("Kleinman’s parameter; Ref.[4,5]")
+        print("NOTE: K = 0 (1) bending (stretching) would dominate")
+        print("K =  %10.5f  " % self.kleinman_parameter)
+        print("")
+        print("Cauchy's Pressure calculated from the relation : CP = C_12 - C_44")
+        print("     CP > 0 (+ve) indicates that ionic bonding dominates")
+        print("     CP < 0 (-ve) indicates that covalent bonding dominates")
+
+        print("CP (GPa) =  %10.3f  " % self.cauchy_pressure)
+        print("Bonding is mainly " + self.bonding_type)
+
+        print("\n------------------------------------------------------------------")
+        print("Elastic Anisotropy")
+        print("------------------------------------------------------------------\n")
+
         print(
-            "Universal anisotropy index (Ranganathan and Ostoja-Starzewski method; PRL 101, 055504 (2008)) Au = %10.5f"
-            % self.A_u
+            "Zener's anisotropy (true for cubic crystals only); Az = %6.3f; Ref.[6]"
+            % self.A_z
         )
         print(
-            "Log-Euclidean anisotropy parameter by Christopher M. Kube, AIP Advances 6, 095209 (2016) AL = %10.5f "
-            % self.A_l
+            "Chung-Buessem's anisotropy (true for cubic crystals only); Acb = %6.3f; Ref.[7]"
+            % self.A_cb
+        )
+        print("Universal anisotropy index; Au = %6.3f; Ref.[8]" % self.A_u)
+        print("Log-Euclidean's anisotropy; AL = %6.3f; Ref.[9]" % self.A_l)
+
+        print("\n------------------------------------------------------------------")
+        print("Elastic Wave Velocities and Debye Temperature")
+        print("------------------------------------------------------------------\n")
+
+        print(
+            "Longitudinal wave velocity (vl) : %10.3f m/s; Ref.[10]"
+            % self.velocity_logitudinal,
         )
         print(
-            "\n \t \t  Elastic wave velocities calculated using Navier's equation  (in m/s units) \n"
+            "Transverse wave velocity (vt) : %10.3f m/s; Ref.[10]"
+            % self.velocity_transverse,
         )
-        print("----------------------------------------------- ")
         print(
-            "Longitudinal wave velocity (vl) : %10.5f m/s " % self.velocity_logitudinal
+            "Average wave velocity (vm) : %10.3f m/s; Ref.[10]" % self.velocity_average,
         )
-        print("Transverse wave velocity (vt) : %10.5f m/s" % self.velocity_transverse)
-        print("Average wave velocity (vm) : %10.5f m/s" % self.velocity_average)
-        print("Debye temperature  (in K) : %10.5f " % self.debye_temperature)
+        print("Debye temperature  : %10.3f K; Ref.[10]" % self.debye_temperature)
+        print("")
         print(
-            "WARNING: Debye model for the atomic displacement is based on a monoatomic crystal, here we consider an average mass in case your crystal has several species."
+            "WARNING: The  Debye model for the atomic displacement is based on a monoatomic crystal approximation.\n Here we consider an averaged mass, in case your crystal has several species."
         )
+
         # print(
         #     "Atomic displacement at 150, 300 and 450 K  (in A^2) : %10.5f %10.5f %10.5f"
         #     % (
@@ -749,36 +852,95 @@ class ElasticProperties:
         #         u2FromDebye(mass, natoms, theta, 450.0),
         #     )
         # )
+        print("\n------------------------------------------------------------------")
+        print("Melting Temperature")
+        print("------------------------------------------------------------------\n")
+
         print(
-            "\nMelting temperature calculated from empirical relation: Tm = 607 + 9.3*Kvrh \pm 555 (in K)"
+            "Melting temperature calculated from the empirical relation: Tm = 607 + 9.3*Kvrh \pm 555 (in K); Ref.[11]"
         )
-        print("Tm (in K)=  %10.5f (plus-minus 555 K) " % self.melting_temperature)
-        print("------------------------------------------------------------------ ")
+        print("Tm =  %10.3f K (plus-minus 555 K) " % self.melting_temperature)
+        print("\n")
+        print(
+            "WARNING: This is a crude approximation and its validity needs to be checked! "
+        )
+
+        print("\n------------------------------------------------------------------")
+        print("Hardness Analysis")
+        print("------------------------------------------------------------------\n")
 
-        print("Hardness analysis from 6 different semi-empirical relationships.")
         H1a, H1b, H2, H3, H4, H5 = self.hardness
-        print("------------------------------------------------------------------ ")
-        print("Hardness (H1a) =", "{:.2f}".format(H1a), "GPa", "  Ref.[1]")
-        print("Hardness (H1b) =", "{:.2f}".format(H1b), "GPa", "  Ref.[1]")
-        print("Hardness (H2)  =", "{:.2f}".format(H2), "GPa", "  Ref.[2]")
-        print("Hardness (H3)  =", "{:.2f}".format(H3), "GPa", "  Ref.[3]")
-        print("Hardness (H4)  =", "{:.2f}".format(H4), "GPa", "  Ref.[4]")
-        print("Hardness (H5)  =", "{:.2f}".format(H5), "GPa", "  Ref.[5]")
-        print("References:")
+        print("Hardness (H1a) =", "{:.2f}".format(H1a), "GPa;", "  Ref.[12]")
+        print("Hardness (H1b) =", "{:.2f}".format(H1b), "GPa;", "  Ref.[12]")
+        print("Hardness (H2)  =", "{:.2f}".format(H2), "GPa;", "  Ref.[13]")
+        print("Hardness (H3)  =", "{:.2f}".format(H3), "GPa;", "  Ref.[14]")
+        print("Hardness (H4)  =", "{:.2f}".format(H4), "GPa;", "  Ref.[15]")
+        print("Hardness (H5)  =", "{:.2f}".format(H5), "GPa;", "  Ref.[16]")
+        print("")
         print(
-            "[1] Correlation between hardness and elastic moduli of the covalent crystals. Jiang, et al. (2011)."
+            """Hardness recommendation model:
+        ********************************************************************
+                     Cubic  Hexagonal  Orthorhombic  Rhombohedral  General
+        ********************************************************************
+        Insulator      H2      H1b          H2            H2          H2
+        Semiconductor  H5    H1b, H3                      H2          H5
+        Metal          H1a     H4           H4            H4          H4
+        ********************************************************************
+        Insulator     : bandgap > 2 eV
+        Semiconductor : bandgap < 2 eV
+        Metal         : bandgap = 0 """
+        )
+
+        print("\n------------------------------------------------------------------")
+        print("References")
+        print("------------------------------------------------------------------\n")
+        print(
+            "[1] Necessary and Sufficient Elastic Stability Conditions in Various Crystal Systems. Félix Mouhat and François-Xavier Coudert. Phys. Rev. B (2014)"
         )
         print(
-            "[2] Computational alchemy: the search for new superhard materials. Teter (1998)."
+            "[2] Crystal Structures and Elastic Properties of Superhard IrN2 and IrN3 from First Principles. Zhi-jian Wu et al. Phys. Rev. B (2007)"
         )
         print(
-            "[3] Mechanical and electronic properties of B12-based ternary crystals of orthorhombic phase. Jiang et al. (2010)."
+            "[3]  The rock physics handbook, Cam-bridge university press. G. Mavko, T. Mukerji, J. Dvorkin. Cambridge University Press. (2020)"
         )
         print(
-            "[4] Theoretical investigation on the transition-metal borides with Ta3B4-type structure: A class of hard and refractory materials. Miao et al. (2011)."
+            "[4]  Deformation potentials in silicon. i. uniaxial strain. Leonard Kleinman. Phys.Rev. 128. (1962)"
         )
         print(
-            "[5] Modeling hardness of polycrystalline materials and bulk metallic glasses. Chen et al. (2011)."
+            "[5] Electronic Structure and the Properties of Solids: The Physics of the Chemical Bond. Walter A. Harrison.  (2012)"
+        )
+        print(
+            "[6] Elasticity and Anelasticity of Metals. Clarence M. Zener et al. The Journal of Physical Chemistry. (1949)"
+        )
+        print(
+            "[7] The Elastic Anisotropy of Crystals. D. H. Chung and W. R. Buessem. Journal of Applied Physics (1967)"
+        )
+        print(
+            "[8] Universal Elastic Anisotropy Index. Shivakumar I. Ranganathan et al. Phys. Rev. Lett. (2008)"
+        )
+        print(
+            "[9] Elastic Anisotropy of Crystals. Christopher M. Kube. AIP Advances. (2016)"
+        )
+        print(
+            "[10] A Simplified Method for Calculating the Debye Temperature from Elastic Constants. Orson L.Anderson. Journal of Physics and Chemistry of Solids. (1963)"
+        )
+        print(
+            "[11] Elastic constants versus melting temperature in metals. M.E.Fine et al. Scripta Metallurgica. (1984)"
+        )
+        print(
+            "[12] Correlation between hardness and elastic moduli of the covalent crystals. Jiang, et al. (2011)."
+        )
+        print(
+            "[13] Computational alchemy: the search for new superhard materials. Teter (1998)."
+        )
+        print(
+            "[14] Mechanical and electronic properties of B12-based ternary crystals of orthorhombic phase. Jiang et al. (2010)."
+        )
+        print(
+            "[15] Theoretical investigation on the transition-metal borides with Ta3B4-type structure: A class of hard and refractory materials. Miao et al. (2011)."
+        )
+        print(
+            "[16] Modeling hardness of polycrystalline materials and bulk metallic glasses. Chen et al. (2011)."
         )
 
     @property
@@ -788,7 +950,7 @@ class ElasticProperties:
     @property
     def hardness(self):
         """
-        
+
         Returns
         -------
         float
@@ -816,20 +978,20 @@ class ElasticProperties:
     def cauchy_pressure(self):
         """
         This parameter desceibes the nature of bonding
-        CP > 0 (+ve) indicates that ionic bonding dominates 
+        CP > 0 (+ve) indicates that ionic bonding dominates
         CP < 0 (-ve) indicates that covalent bonding dominates
         Returns
         -------
         None.
 
         """
-        return self.elastic_tensor[0,1]-self.elastic_tensor[3,3]
-    
-    @property 
+        return self.elastic_tensor[0, 1] - self.elastic_tensor[3, 3]
+
+    @property
     def bonding_type(self):
         """
         This parameter desceibes the nature of bonding
-        CP > 0 (+ve) indicates that ionic bonding dominates 
+        CP > 0 (+ve) indicates that ionic bonding dominates
         CP < 0 (-ve) indicates that covalent bonding dominates
 
         Returns
@@ -839,25 +1001,24 @@ class ElasticProperties:
 
         """
         cauchy_pressure = self.cauchy_pressure
-        if cauchy_pressure > 0 :
-            return "Ionic"
-        elif cauchy_pressure < 0 :
-            return "Covalent"
-        
-    @property 
+        if cauchy_pressure > 0:
+            return "ionic"
+        elif cauchy_pressure < 0:
+            return "covalent"
+
+    @property
     def kleinman_parameter(self):
         c = self.elastic_tensor
-        return (c[0,0]+8*c[0,1])/(7*c[0,0]-2*c[0,1])
-    
-    @property 
+        return (c[0, 0] + 8 * c[0, 1]) / (7 * c[0, 0] - 2 * c[0, 1])
+
+    @property
     def bond_bending_vs_streching(self):
         return
-    
-    
+
     @property
     def lambda_lame_coefficient(self):
         """
-        
+
 
         Returns
         -------
@@ -865,10 +1026,44 @@ class ElasticProperties:
             DESCRIPTION.
 
         """
-        return self.E_vrh/((1+self.Nu_vrh)*(1-2*self.Nu_vrh))
-    
+        return self.E_vrh / ((1 + self.Nu_vrh) * (1 - 2 * self.Nu_vrh))
+
     @property
     def mu_lame_coefficient(self):
-        return self.E_vrh/(2*(1+self.Nu_vrh))
+        return self.E_vrh / (2 * (1 + self.Nu_vrh))
 
-    
\ No newline at end of file
+
+def positive_evals(cnew):
+    """This method checks the postivity of the eigenvalues
+    of a matrix."""
+
+    # print("Eigen Values of the matrix:")
+    evals = list(LA.eigvals(cnew))
+    evalsPrint = list(np.around(np.array(evals), 3))
+    print("%s" % evalsPrint)
+    check = 0
+    for i in range(len(evals)):
+        if evals[i] > 0.0:
+            pass
+        else:
+            check = 1
+    # if check == 1:
+    #     print(
+    #         "ATTENTION: One or more eigen values are negative indicating elastic instability."
+    #     )
+    # if check == 0:
+    #     print("All eigen values are positive indicating elastic stability.")
+
+    return not (bool(check))
+
+
+def printMatrix(c):
+    row = c.shape[0]
+    col = c.shape[1]
+    for i in range(row):
+        for j in range(col):
+            print("{:>10.3f} ".format(c[i, j]), end=" ")
+            if j == (col - 1):
+                print(" ")
+
+    return
